##Player-Piano analysis script --> redo with full data, post peer review, January 2024
##created by Dr. Maximilian Rosenthal, last date 16 Jan 2024
##file paths need to be individually adjusted for each import function ("<-read.csv")

#0) Load packages and data
#1) January 2024: check for updated data where previously missing
#2) Create datasets
#3) Calculate counts and sums
#4) Generate yearly data
#5) Isolate respective Top-20-editions
#6) analyse break points

# 0) Load packages and data
pacman::p_load(pacman, scales, lubridate, rio, tidyverse, car, ggplot2, dplyr, magrittr, Hmisc, GGally, lsr, rjson, jsonlite, forecast, strucchange)
##--> this is my standard range of packages I load for working with mvdb data
Abzug_polished_5b<-read.csv("***insert correct path here***/master_2.csv", fileEncoding = "UTF-8")
##--> loading of mvdb data, extracted via API, date October 2023

# 1) January 2024: check for updated data where previously missing
##a) individual checks for previously missing data
castro<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID)%>%
  unique%>%
  filter(grepl("Castro", KOMPONIST))
dvorak<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID)%>%
  unique%>%
  filter(grepl("Antoni´n", KOMPONIST))
henselt<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID)%>%
  unique%>%
  filter(grepl("Henselt", KOMPONIST))
jaell<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID)%>%
  unique%>%
  filter(grepl("Alfred", KOMPONIST))
Joseffy<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID)%>%
  unique%>%
  filter(grepl("Jose", KOMPONIST))
#keine treffer?
Liebich<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID, WERK_GND_ID)%>%
  unique%>%
  filter(grepl("Liebi", KOMPONIST))
Liszt<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID, WERK_GND_ID, VERLAG)%>%
  unique%>%
  filter(VERLAG=="HO")%>%
  filter(grepl("Liszt", KOMPONIST))
Lorleberg<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID, WERK_GND_ID)%>%
  unique%>%
  filter(grepl("Lorleberg", KOMPONIST))
Lysberg<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID, WERK_GND_ID)%>%
  unique%>%
  filter(grepl("Lysberg", KOMPONIST))
Popper<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID, WERK_GND_ID)%>%
  unique%>%
  filter(grepl("Popper", KOMPONIST))
Reh<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID, WERK_GND_ID)%>%
  unique%>%
  filter(grepl("Reh", KOMPONIST))
Richards<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID, WERK_GND_ID)%>%
  unique%>%
  filter(grepl("Richards", KOMPONIST))
Rubinstein<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID, WERK_GND_ID)%>%
  unique%>%
  filter(grepl("Anton G.", KOMPONIST))
Sartorio<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID, WERK_GND_ID)%>%
  unique%>%
  filter(grepl("Sartorio", KOMPONIST))
Schulhoff<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID, WERK_GND_ID)%>%
  unique%>%
  filter(grepl("Schulhoff", KOMPONIST))
Vogrich<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID, WERK_GND_ID)%>%
  unique%>%
  filter(grepl("Vogrich", KOMPONIST))
works<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID, WERK_GND_ID, WERK_VOLLER_TITEL)%>%
  unique%>%
  filter(WERK_GND_ID=="1079072802")
#free_search<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, MVDB_ID)%>%
#  unique%>%
#  filter(grepl("*", AUSGABENTITEL))

##b) double check by Work-GND-ID
GND.IDs<-read.csv("***insert correct path here***/GND-IDs.csv", encoding="UTF-8", sep="")
GNDs<-c(GND.IDs$GND)
GND_list<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, VERLAGSARTIKEL_ID, WERK_GND_ID)%>%
  unique%>%
  filter(WERK_GND_ID %in% GNDs)

#2) Create Datasets
##a) Full Dataset
Full_set<-Abzug_polished_5b%>%select(KOMPONIST, WERK_OPUS_ZAHL, WERK_GND_ID, WERK_VOLLER_TITEL, GENRE_GND, BESETZUNG_GND_INSTRUMENT, REALER_KOMPONIST, AUSGABENTITEL, KOMBINIERTE_GENRES_REAL, KOMBINIERTE_BESETZUNG_REAL, AUSGABEFORM, VERLAGSARTIKEL_ID, VERLAGSNUMMER, TEIL, MVDB_ID, DRUCKDATUM, DRUCKMENGE, DRUCKMENGE_BEREINIGT, DRUCK_UID)%>%
  unique%>%        
  mutate(Jahr=year(DRUCKDATUM), Verlag=substr(VERLAGSARTIKEL_ID, 0,2))%>%
  filter(Verlag=="HO")%>%
  filter(is.na(Jahr)|Jahr>="1800")%>%
  filter(is.na(Jahr)|Jahr<="1945")
write.csv(Full_set, "***insert correct path here***/Full_set.csv")

##b) Dataset Player_Piano
### refine Teilausgaben, create filter
###older code: Pianolas<-c("HO_02242", "HO_02257", "HO_02276", "HO_02277", "HO_02257" ,"HO_02610", "HO_02628", "HO_02685", "HO_02896", "HO_02974", "HO_02977", "HO_04005", "HO_04485", "HO_04711", "HO_04813", "HO_04872", "HO_04939", "HO_04967", "HO_05020", "HO_05021", "HO_05056", "HO_05073", "HO_05106", "HO_05212","HO_05224", "HO_05242", "HO_05278", "HO_05279", "HO_05536", "HO_05639", "HO_05691", "HO_05704", "HO_05707", "HO_05721", "HO_05722", "HO_05730", "HO_05755", "HO_05841", "HO_05843", "HO_05884", "HO_05996", "HO_06041", "HO_06135", "HO_06481", "HO_06803", "HO_06937", "HO_06978", "HO_07045", "HO_07046", "HO_07665", "HO_07683", "HO_07685", "HO_07686", "HO_07776", "HO_07776", "HO_07782", "HO_07812", "HO_07823", "HO_07825", "HO_07826", "HO_07830", "HO_07838", "HO_07856", "HO_07863", "HO_07953", "HO_07960", "HO_07980", "HO_07992", "HO_08041", "HO_0882a", "HO_08142", "HO_08235", "HO_08365", "HO_08368", "HO_08468", "HO_08586", "HO_08608", "HO_08616", "HO_08635", "HO_08648", "HO_08652", "HO_08653", "HO_08654", "HO_08660", "HO_08661", "HO_08696", "HO_08764", "HO_08775", "HO_08776")
ID_list<-read.csv("***insert correct path here***/ID_list.csv", sep="")
IDs<-c(ID_list$ID)
ID.list<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, VERLAGSARTIKEL_ID, MVDB_ID, VERLAGSNUMMER, WERK_GND_ID, WERK_VOLLER_TITEL)%>%
  unique%>%
  filter(VERLAGSARTIKEL_ID %in% IDs)

Player_Piano<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, AUSGABEFORM, VERLAGSARTIKEL_ID, VERLAGSNUMMER, TEIL, MVDB_ID, DRUCKDATUM, DRUCKMENGE, DRUCK_UID, WERK_VOLLER_TITEL, WERK_GND_ID, WERK_OPUS_ZAHL)%>%
  unique%>%
  filter(VERLAGSARTIKEL_ID %in% IDs)%>%
  mutate(Jahr=year(DRUCKDATUM))%>%
  filter(Jahr>=1800)%>%
  filter(Jahr<=1945)%>%
  group_by(MVDB_ID)%>%
  mutate(Firstpub=min(DRUCKDATUM))%>%
  mutate(Publikationsjahr=year(Firstpub))%>%
  filter(Publikationsjahr<1902)%>%
  filter(MVDB_ID!="HO_02257_02257_N1_N",
         MVDB_ID!="HO_02257_02257_N2_N",
         MVDB_ID!="HO_02257_02257_N3_N", 
         MVDB_ID!="HO_02257_02257_N4_N", 
         MVDB_ID!="HO_02257_02257_N5_N", 
         MVDB_ID!="HO_02257_02257_N7_N", 
         MVDB_ID!="HO_02257_02257_N8_N",
         MVDB_ID!="HO_02257_02257_N9_N", 
         MVDB_ID!="HO_02257_02257_N10_N",
         MVDB_ID!="HO_02340_02340_H1_N",
         MVDB_ID!="HO_02974_02974_N1_N", 
         MVDB_ID!="HO_02974_02975_NN_N2", #factually wrong signature, has to be used here, but is corrected in mvdb 05.1.2024
         MVDB_ID!="HO_04005_04006_H2_Cplt", 
         MVDB_ID!="HO_04005_04005_N1_N", 
         MVDB_ID!="HO_04005_04005_N2_N", 
         MVDB_ID!="HO_04005_04005_N3_N",
         MVDB_ID!="HO_04005_04005_N5_N", 
         MVDB_ID!="HO_04005_04006_N6_N", 
         MVDB_ID!="HO_04005_04006_N7_N", 
         MVDB_ID!="HO_04005_04006_N8_N", 
         MVDB_ID!="HO_04005_04006_N9_N",
         MVDB_ID!="HO_04005_04006_N10_N",
         MVDB_ID!="HO_04939_04941_N3_N",
         MVDB_ID!="HO_07960_07962_N3_K4h"
          )%>%
  ungroup
write.csv(Player_Piano, "***insert correct path here***/Player_Piano.csv")
## neglected: Rubinstein, Sartorio u.a. in Schick Mandolin editions, e.g. Nr. 8586, 8588, 8589, 8590
## --> Rubinstein HO_7960 to 7962 creates double lines bc. double WERK-ascriptions

##c) Dataset No_Player_Piano
###create filter
"%ni%"<-Negate("%in%")
Precise_PPfilter<-Player_Piano$MVDB_ID

No_Player_Piano<-Abzug_polished_5b%>%select(KOMPONIST, AUSGABENTITEL, AUSGABEFORM, VERLAGSARTIKEL_ID, VERLAGSNUMMER, TEIL, MVDB_ID, DRUCKDATUM, DRUCKMENGE, DRUCK_UID, WERK_VOLLER_TITEL, WERK_GND_ID, WERK_OPUS_ZAHL)%>%
  unique%>%        
  mutate(Jahr=year(DRUCKDATUM), Verlag=substr(VERLAGSARTIKEL_ID, 0,2))%>%
  filter(Verlag=="HO")%>%
  filter(Jahr>="1800")%>%
  filter(Jahr<="1945")%>%
  group_by(MVDB_ID)%>%
  mutate(Firstpub=min(DRUCKDATUM))%>%
  mutate(Publikationsjahr=year(Firstpub))%>%
  filter(Publikationsjahr<1902)%>%
  filter(MVDB_ID %ni% Precise_PPfilter)%>%
  ungroup
write.csv(No_Player_Piano, "***insert correct path here***/No_Player_Piano.csv")

#3) calculate counts and sums
##a)Player_Piano
#works_PP<-Player_Piano%>%group_by(KOMPONIST, WERK_VOLLER_TITEL, WERK_OPUS_ZAHL)%>%summarise(Total = sum(DRUCKMENGE))
#editions_PP<-Player_Piano%>%group_by(KOMPONIST, AUSGABENTITEL, VERLAGSARTIKEL_ID)%>%group_by(KOMPONIST, AUSGABENTITEL, VERLAGSARTIKEL_ID)%>%summarise(Total = sum(DRUCKMENGE))
## --> "Werke" count and sums as written in the paper follows simplified grouping in Tabelle 1
## --> "Ausgaben" and "Teilausgaben" count and sums as written in paper based on exported data --> deleted redundant Rubinstein lines --> Pivot table

##b)No_Player_Piano
works_no_PP<-No_Player_Piano%>%
  select(WERK_VOLLER_TITEL, WERK_GND_ID, DRUCK_UID, DRUCKMENGE)%>%
  unique%>%
  group_by(WERK_VOLLER_TITEL, WERK_GND_ID)%>%
  summarise(Total = sum(DRUCKMENGE))
editions_no_PP<-No_Player_Piano%>%
  select(AUSGABENTITEL, VERLAGSARTIKEL_ID, DRUCK_UID, DRUCKMENGE)%>%
  unique%>%
  group_by(AUSGABENTITEL, VERLAGSARTIKEL_ID)%>%
  summarise(Total = sum(DRUCKMENGE))
plates_no_PP<-No_Player_Piano%>%
  select(AUSGABENTITEL, VERLAGSARTIKEL_ID, VERLAGSNUMMER, DRUCK_UID, DRUCKMENGE)%>%
  unique%>%
  group_by(AUSGABENTITEL, VERLAGSARTIKEL_ID, VERLAGSNUMMER)%>%
  summarise(Total = sum(DRUCKMENGE))
partial_no_PP<-No_Player_Piano%>%
  select(AUSGABENTITEL, VERLAGSARTIKEL_ID, MVDB_ID, DRUCK_UID, DRUCKMENGE)%>%
  unique%>%
  group_by(AUSGABENTITEL, VERLAGSARTIKEL_ID, MVDB_ID)%>%
  summarise(Total = sum(DRUCKMENGE))
summary(editions_no_PP$Total)
write.csv(editions_no_PP, "***insert correct path here***/editions_no_PP.csv")
#> summary(editions_no_PP$Total)
#Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#4.0   150.0   250.0   591.2   450.0 83995.0 

#4) Generate yearly data
##a) Player_Piano
PP_yearly<-Player_Piano%>%select(DRUCK_UID, DRUCKDATUM, DRUCKMENGE)%>%
  unique%>%
  mutate(Jahr=year(DRUCKDATUM))%>%
  group_by(Jahr)%>%
  summarise(Total = sum(DRUCKMENGE))
Jahr<-c(1837:1945)
dummy<-(1:109)
Jahre<-data.frame(Jahr, dummy)
PP_yearly_final<-left_join(Jahre, PP_yearly, by="Jahr")%>%
  replace(is.na(.), 0)%>%
  select(Jahr, Total)%>%
  mutate(GD = ma(Total, 7))
plot(PP_yearly_final$Jahr, PP_yearly_final$Total, type="l")
lines(PP_yearly_final$Jahr, PP_yearly_final$GD, col = "red")
write.csv(PP_yearly_final, "***insert correct path here***/PP_yearly.csv")

##b) No_Player_Piano
noPP_yearly<-No_Player_Piano%>%select(DRUCK_UID, DRUCKDATUM, DRUCKMENGE)%>%
  unique%>%
  mutate(Jahr=year(DRUCKDATUM))%>%
  group_by(Jahr)%>%
  summarise(Total = sum(DRUCKMENGE))
Jahr<-c(1808:1945)
dummy<-(1:138)
Jahre<-data.frame(Jahr, dummy)
noPP_yearly_final<-left_join(Jahre, noPP_yearly, by="Jahr")%>%
  replace(is.na(.), 0)%>%
  select(Jahr, Total)%>%
  mutate(GD = ma(Total, 7))
plot(noPP_yearly_final$Jahr, noPP_yearly_final$Total, type="l")
lines(noPP_yearly_final$Jahr, noPP_yearly_final$GD, col = "blue")
write.csv(noPP_yearly_final, "***insert correct path here***/noPP_yearly.csv")

##c) global (to compute shares of total)
Full_yearly<-Full_set%>%
  group_by(MVDB_ID)%>%
  mutate(Firstpub=min(DRUCKDATUM))%>%
  mutate(Publikationsjahr=year(Firstpub))%>%
  filter(Publikationsjahr<1902)%>%
  ungroup%>%
  select(Jahr, DRUCKMENGE, DRUCK_UID)%>%
  unique%>%
  group_by(Jahr)%>%
  summarise(Total = sum(DRUCKMENGE))
Jahr<-c(1808:1945)
dummy<-(1:138)
Jahre<-data.frame(Jahr, dummy)
Full_yearly_final<-left_join(Jahre, Full_yearly, by="Jahr")%>%
  replace(is.na(.), 0)%>%
  select(Jahr, Total)%>%
  mutate(GD = ma(Total, 7))
plot(Full_yearly_final$Jahr, Full_yearly_final$Total, type="l")
lines(Full_yearly_final$Jahr, Full_yearly_final$GD, col = "blue")
write.csv(Full_yearly_final, "***insert correct path here***/full_yearly.csv")

#--> further investigation and plots in Excel for aesthetic reasons mostly

##d) correlation tests
cor.test(X01a_erste_Differenzen$`no PP`, X01a_erste_Differenzen$PP)
#t = 3.03, df = 103, p-value = 0.003092
#alternative hypothesis: true correlation is not equal to 0
#95 percent confidence interval:
#  0.09989246 0.45291177
#sample estimates:
#  cor 
#0.2860804 
pre_war<-X01a_erste_Differenzen[-c(78:105),]
post_war<-X01a_erste_Differenzen[-c(1:77),]
cor.test(pre_war$`no PP`, pre_war$PP)
#t = 2.1672, df = 75, p-value = 0.0334
#alternative hypothesis: true correlation is not equal to 0
#95 percent confidence interval:
#  0.01985782 0.44266690
#sample estimates:
#  cor 
#0.2427569 
cor.test(post_war$`no PP`, post_war$PP)
#t = 1.9406, df = 26, p-value = 0.06322
#alternative hypothesis: true correlation is not equal to 0
#95 percent confidence interval:
#  -0.02003477  0.64339662
#sample estimates:
#  cor 
#0.3557009
time_1902_1913<-X01a_erste_Differenzen[c(66:77),]
cor.test(time_1902_1913$`no PP`, time_1902_1913$PP)
#data:  time_1902_1913$`no PP` and time_1902_1913$PP
#t = 3.2138, df = 10, p-value = 0.009272
#alternative hypothesis: true correlation is not equal to 0
#95 percent confidence interval:
#  0.2350505 0.9131516
#sample estimates:
#  cor 
#0.7127985


#5) Isolate respective Top-20-titles
##a) different sums
Full_top20_1902<-Full_set%>%
  group_by(MVDB_ID)%>%
  mutate(Firstpub=min(DRUCKDATUM))%>%
  mutate(Publikationsjahr=year(Firstpub))%>%
  filter(Publikationsjahr<1902)%>%
  filter(Jahr<1902)%>%
  select(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER, DRUCKMENGE, DRUCK_UID)%>%
  unique%>%
  group_by(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER)%>%
  summarise(Total = sum(DRUCKMENGE))%>%
  arrange(desc(Total))
?arrange
write.csv(Full_top20_1902, "***insert correct path here***/full_top20_1902.csv")

PP_top20_1902<-Player_Piano%>%
  filter(Jahr<1902)%>%
  select(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER, DRUCKMENGE, DRUCK_UID)%>%
  unique%>%
  group_by(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER)%>%
  summarise(Total = sum(DRUCKMENGE))
write.csv(PP_top20_1902, "***insert correct path here***/PP_top20_1902.csv")

NoPP_top20_1902<-No_Player_Piano%>%
  filter(Jahr<1902)%>%
  select(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER, DRUCKMENGE, DRUCK_UID)%>%
  unique%>%
  group_by(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER)%>%
  summarise(Total = sum(DRUCKMENGE))
write.csv(NoPP_top20_1902, "***insert correct path here***/NoPP_top20_1902.csv")

Full_top20_1945<-Full_set%>%
  group_by(MVDB_ID)%>%
  mutate(Firstpub=min(DRUCKDATUM))%>%
  mutate(Publikationsjahr=year(Firstpub))%>%
  filter(Publikationsjahr<1902)%>%
  filter(Jahr<=1945)%>%
  select(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER, DRUCKMENGE, DRUCK_UID)%>%
  unique%>%
  group_by(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER)%>%
  summarise(Total = sum(DRUCKMENGE))

PP_top20_1890<-Player_Piano%>%
  filter(Jahr<1890)%>%
  select(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER, DRUCKMENGE, DRUCK_UID)%>%
  unique%>%
  group_by(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER)%>%
  summarise(Total = sum(DRUCKMENGE))

NoPP_top20_1890<-No_Player_Piano%>%
  filter(Jahr<1890)%>%
  select(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER, DRUCKMENGE, DRUCK_UID)%>%
  unique%>%
  group_by(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER)%>%
  summarise(Total = sum(DRUCKMENGE))

PP_top20_1914<-Player_Piano%>%
  filter(Jahr<1914)%>%
  select(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER, DRUCKMENGE, DRUCK_UID)%>%
  unique%>%
  group_by(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER)%>%
  summarise(Total = sum(DRUCKMENGE))

NoPP_top20_1914<-No_Player_Piano%>%
  filter(Jahr<1914)%>%
  select(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER, DRUCKMENGE, DRUCK_UID)%>%
  unique%>%
  group_by(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER)%>%
  summarise(Total = sum(DRUCKMENGE))


##b) create yearly
PP_top20_1902_cut<-Player_Piano%>%
  filter(Jahr<1902)%>%
  select(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER, DRUCKMENGE, DRUCK_UID)%>%
  unique%>%
  group_by(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER)%>%
  summarise(Total = sum(DRUCKMENGE))%>%
  arrange(desc(Total))
PP_top20_1902_cut<-PP_top20_1902_cut[c(1:20),]
PP_top20_yearly<-Player_Piano%>%
  filter(VERLAGSNUMMER %in% PP_top20_1902_cut$VERLAGSNUMMER)%>%
  select(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER, Jahr, DRUCKMENGE, DRUCK_UID)%>%
  unique%>%
  group_by(Jahr)%>%
  summarise(Total = sum(DRUCKMENGE))
Jahr<-c(1838:1945)
dummy<-(1:108)
Jahre<-data.frame(Jahr, dummy)
PP_top20_yearly_final<-left_join(Jahre, PP_top20_yearly, by="Jahr")%>%
  replace(is.na(.), 0)%>%
  select(Jahr, Total)

NoPP_top20_1902_cut<-No_Player_Piano%>%
  filter(Jahr<1902)%>%
  select(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER, DRUCKMENGE, DRUCK_UID)%>%
  unique%>%
  group_by(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER)%>%
  summarise(Total = sum(DRUCKMENGE))%>%
  arrange(desc(Total))
NoPP_top20_1902_cut<-NoPP_top20_1902_cut[c(1:6, 8:21),]
NoPP_top20_yearly<-No_Player_Piano%>%
  filter(VERLAGSNUMMER %in% NoPP_top20_1902_cut$VERLAGSNUMMER)%>%
  mutate(KOMPONIST=ifelse(VERLAGSNUMMER == "01909", "Marschner, Heinrich", KOMPONIST))%>%
  select(KOMPONIST, AUSGABENTITEL, VERLAGSNUMMER, Jahr, DRUCKMENGE, DRUCK_UID)%>%
  unique%>%
  group_by(Jahr, AUSGABENTITEL)%>%
  summarise(Total = sum(DRUCKMENGE))
Jahr<-c(1828:1945)
dummy<-(1:118)
Jahre<-data.frame(Jahr, dummy)
NoPP_top20_yearly_final<-left_join(Jahre, NoPP_top20_yearly, by="Jahr")%>%
  replace(is.na(.), 0)%>%
  select(Jahr, Total)
  
#6) analyse Breakpoints
##a) create timeseries-object PP
PP_ts<-ts(PP_yearly_final$Total, freq=1, start=PP_yearly_final$Jahr[1])
summary(lm(PP_ts ~ 1))
break_point<-breakpoints(PP_ts ~ 1)
summary(break_point)
plot(PP_ts)
fitted_PP<-fitted(break_point, breaks=4)
lines(fitted_PP, col=3)
lines(confint(break_point, breaks=4))

##b) create timeseries-object only until 1914
PP_yearly_1914<-PP_yearly_final[c(1:77),]
PP_ts_1914<-ts(PP_yearly_1914$Total, freq=1, start=PP_yearly_1914$Jahr[1])
summary(lm(PP_ts_1914 ~ 1))
break_point<-breakpoints(PP_ts_1914 ~ 1)
summary(break_point)
plot(PP_ts_1914)
fitted_PP<-fitted(break_point, breaks=2)
lines(fitted_PP, col=3)
lines(confint(break_point, breaks=2))

##c) create timeseries with full PP-set (including published after 1901)
PP_yearly_all<-Player_Piano%>%
  select(Jahr, DRUCKMENGE, DRUCK_UID)%>%
  unique%>%
  group_by(Jahr)%>%
  summarise(Total = sum(DRUCKMENGE))
Jahr<-c(1838:1945)
dummy<-(1:108)
Jahre<-data.frame(Jahr, dummy)
PP_yearly_all_final<-left_join(Jahre, PP_yearly_all, by="Jahr")%>%
  replace(is.na(.), 0)%>%
  select(Jahr, Total)
plot(PP_yearly_all_final)

PP_all_ts<-ts(PP_yearly_all_final$Total, freq=1, start=PP_yearly_final$Jahr[1])
summary(lm(PP_all_ts ~ 1))
break_point<-breakpoints(PP_all_ts ~ 1)
summary(break_point)
plot(PP_all_ts)
fitted_PP<-fitted(break_point, breaks=4)
lines(fitted_PP, col=3)
lines(confint(break_point, breaks=4))
